@@ -21,6 +21,7 @@ class WebDriver (ElementLocation):
         webdriverName,
         headless=False,
         maximized=False,
+        custom_driver=None,
         custom_chrome_options=False,
         custom_firefox_options=False,
         firefox_binary_location=False,
@@ -65,7 +66,7 @@ class WebDriver (ElementLocation):
             logging.basicConfig(level=logging_level)
         
         #Set webdriver name for class
-        self.webdriverName=webdriverName
+        self.webdriverName=webdriverName.lower()
         
         #Get & set webdriver location through webdriver manager
         webdriverLocation=WebdriverManager().installWebdriverIfNeededAndGetDownloadLocation(webdriverName)
@@ -86,6 +87,7 @@ class WebDriver (ElementLocation):
         self.startupOptions={}
         self.startupOptions['headless']=headless
         self.startupOptions['maximized']=maximized
+        self.startupOptions['custom_driver']=custom_driver
         self.startupOptions['custom_chrome_options']=custom_chrome_options
         self.startupOptions['custom_firefox_options']=custom_firefox_options
         self.startupOptions['firefox_binary_location']=firefox_binary_location
@@ -295,6 +297,10 @@ class WebDriver (ElementLocation):
             #Return true to indicate successful webdriver start
             return True
 
+        if self.webdriverName=="custom":
+            #Gets custom driver object
+            self.driver=startupOptions['custom_driver']
+
         #Set driver
         self.driver=driver
 
@@ -526,13 +532,13 @@ class WebDriver (ElementLocation):
         return self.driver.set_script_timeout(time_to_wait)
 
     def set_user_verified(self,verified: bool):
-        return self.driver.set_user_verified(time_to_wait)
+        return self.driver.set_user_verified(verified)
 
     def set_window_position(self,x,y,windowHandle: str = 'current'):
         return self.driver.set_window_position(x,y,windowHandle)
 
-    def set_window_rect(self,x=None, y=None, width=None, height=None):
-        return self.driver.set_window_rect(x,y,width,height)
+    #def set_window_rect(self,x=None, y=None, width=None, height=None):
+    #    return self.driver.set_window_rect(x,y,width,height)
 
     def set_window_size(self,width, height, windowHandle: str = 'current'):
         return self.driver.set_window_size(width, height, windowHandle)
